@@ -74,6 +74,18 @@ function activate_venv(){
     errexit "Error: can't activate python3 environment."
   fi
 }
+function has_untracked_files(){
+  [ "$(git status --porcelain 2>/dev/null | grep -Ec '^(M| M|\?\?|u) ')" != 0 ]
+}
+function require_working_directory_clean(){
+  if has_untracked_files; then
+    echo "Working directory is not clean." 1>&2
+    git status
+    false
+  else
+    true
+  fi
+}
 
 function do_action(){
   case "$1" in
@@ -163,6 +175,36 @@ function do_action(){
       usage
     ;;
 
+    prerelease)
+      run "Ensure working directory is clean." require_working_directory_clean
+      do_action unit-test
+      do_action coverage
+      do_action quality
+      do_action style
+      do_action docs
+    ;;
+
+    release-major)
+      do_action prerelease
+      run "Increment the version number (major)." bumpversion minor
+      run "Push changes" git push
+      run "Push tags"    git push --tags
+    ;;
+
+    release-minor)
+      do_action prerelease
+      run "Increment the version number (minor)." bumpversion minor
+      run "Push changes" git push
+      run "Push tags"    git push --tags
+    ;;
+
+    release-patch)
+      do_action prerelease
+      run "Increment the version number (patch)." bumpversion minor
+      run "Push changes" git push
+      run "Push tags"    git push --tags
+    ;;
+
     *)
       errexit "Unknown action '$1'. Try '$0 --help' for more information."
     ;;
